@@ -4,44 +4,45 @@ use Exporter ();
 @EXPORT = qw(%Config);
 @EXPORT_OK = qw(myconfig config_sh config_vars);
 
-$] == 5.00307
-  or die "Perl lib version (5.00307) doesn't match executable version ($])";
+$] == 5.00404
+  or die "Perl lib version (5.00404) doesn't match executable version ($])";
 
 # This file was created by configpm when Perl was built. Any changes
 # made to this file will be lost the next time perl is built.
 
 ##
-## This file was produced by running the Configure script. It holds all the
-## definitions figured out by Configure. Should you modify one of these values,
-## do not forget to propagate your changes by running "Configure -der". You may
-## instead choose to run each of the .SH files by yourself, or "Configure -S".
+## This file was produced by running the Configure script.  It holds all
+## the definitions figured out by Configure.  Should you modify any of
+## these values, do not forget to propagate your changes by running
+## "Configure -S"; or, equivalently, you may run each .SH file yourself.
 ##
 #
-## Configuration time: Mon Apr 21 21:16:16 PDT 1997
+## Configuration time: Fri Jun  5 01:27:29 PDT 1998
 ## Configured by: torin
-## Target system: linux kitchen 2.0.27 #3 wed jan 1 12:41:58 pst 1997 i586 unknown 
+## Target system: linux kitchen 2.0.34 #2 fri may 22 00:08:40 pdt 1998 i586 unknown 
 #
 
 my $config_sh = <<'!END!';
-archlibexp='/usr/lib/perl5/i386-linux/5.00307'
+archlibexp='/usr/lib/perl5/i386-linux/5.004'
 archname='i386-linux'
 cc='cc'
-ccflags='-Dbool=char -DHAS_BOOL -I/usr/include/db -D_REENTRANT'
-cppflags='-Dbool=char -DHAS_BOOL -I/usr/include/db -D_REENTRANT'
+ccflags='-Dbool=char -DHAS_BOOL -D_REENTRANT'
+cppflags='-Dbool=char -DHAS_BOOL -D_REENTRANT'
 dlsrc='dl_dlopen.xs'
-dynamic_ext='DB_File Fcntl FileHandle GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
-extensions='DB_File Fcntl FileHandle GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
-installarchlib='/usr/lib/perl5/i386-linux/5.00307'
+dynamic_ext='DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
+extensions='DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
+installarchlib='/usr/lib/perl5/i386-linux/5.004'
 installprivlib='/usr/lib/perl5'
 libpth='/usr/local/lib /lib /usr/lib'
-libs='-lndbm -lgdbm -ldbm -ldb -ldl -lm -lc'
+libs='-lnsl -lndbm -lgdbm -ldbm -ldb -ldl -lm -lc -lposix -lcrypt'
 osname='linux'
-osvers='2.0.27'
+osvers='2.0.34'
 prefix='/usr'
 privlibexp='/usr/lib/perl5'
 sharpbang='#!'
 shsharp='true'
 sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR UNUSED IOT CLD POLL '
+sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 6 17 29 '
 so='so'
 startsh='#!/bin/sh'
 static_ext=' '
@@ -53,22 +54,23 @@ Id='$Id'
 Locker=''
 Log='$Log'
 Mcc='Mcc'
-PATCHLEVEL='3'
+PATCHLEVEL='4'
 RCSfile='$RCSfile'
 Revision='$Revision'
-SUBVERSION='7'
+SUBVERSION='4'
 Source=''
 State=''
 afs='false'
 alignbytes='4'
 aphostname=''
 ar='ar'
-archlib='/usr/lib/perl5/i386-linux/5.00307'
+archlib='/usr/lib/perl5/i386-linux/5.004'
 archobjs=''
 awk='awk'
 baserev='5.0'
 bash=''
 bin='/usr/bin'
+bincompat3='n'
 binexp='/usr/bin'
 bison=''
 byacc='byacc'
@@ -80,7 +82,7 @@ cccdlflags='-fpic'
 ccdlflags='-rdynamic'
 cf_by='torin'
 cf_email='torin@kitchen.bazilians.org'
-cf_time='Mon Apr 21 21:16:16 PDT 1997'
+cf_time='Fri Jun  5 01:27:29 PDT 1998'
 chgrp=''
 chmod=''
 chown=''
@@ -98,13 +100,14 @@ cpprun='cc -E'
 cppstdin='cc -E'
 cryptlib=''
 csh='csh'
-d_Gconvert='sprintf((b),"%.*g",(n),(x))'
+d_Gconvert='gcvt((x),(n),(b))'
 d_access='define'
 d_alarm='define'
 d_archlib='define'
 d_attribut='define'
 d_bcmp='define'
 d_bcopy='define'
+d_bincompat3='undef'
 d_bsd='undef'
 d_bsdgetpgrp='undef'
 d_bsdpgrp='undef'
@@ -143,6 +146,7 @@ d_flock='define'
 d_fork='define'
 d_fpathconf='define'
 d_fsetpos='define'
+d_ftime='undef'
 d_getgrps='define'
 d_gethent='define'
 d_gethname='undef'
@@ -152,9 +156,11 @@ d_getpgrp2='undef'
 d_getpgrp='define'
 d_getppid='define'
 d_getprior='define'
-d_gnulibc='undef'
+d_gettimeod='define'
+d_gnulibc='define'
 d_htonl='define'
 d_index='undef'
+d_inetaton='define'
 d_isascii='define'
 d_killpg='define'
 d_link='define'
@@ -185,7 +191,7 @@ d_pathconf='define'
 d_pause='define'
 d_phostname='undef'
 d_pipe='define'
-d_poll='undef'
+d_poll='define'
 d_portable='define'
 d_pwage='undef'
 d_pwchange='undef'
@@ -200,6 +206,7 @@ d_rewinddir='define'
 d_rmdir='define'
 d_safebcpy='define'
 d_safemcpy='undef'
+d_sanemcmp='define'
 d_seekdir='define'
 d_select='define'
 d_sem='define'
@@ -208,6 +215,7 @@ d_semget='define'
 d_semop='define'
 d_setegid='define'
 d_seteuid='define'
+d_setgrps='define'
 d_setlinebuf='define'
 d_setlocale='define'
 d_setpgid='define'
@@ -232,7 +240,7 @@ d_sigaction='define'
 d_sigsetjmp='define'
 d_socket='define'
 d_sockpair='define'
-d_statblks='define'
+d_statblks='undef'
 d_stdio_cnt_lval='undef'
 d_stdio_ptr_lval='define'
 d_stdiobase='define'
@@ -242,6 +250,9 @@ d_strcoll='define'
 d_strctcpy='define'
 d_strerrm='strerror(e)'
 d_strerror='define'
+d_strtod='define'
+d_strtol='define'
+d_strtoul='define'
 d_strxfrm='define'
 d_suidsafe='undef'
 d_symlink='define'
@@ -291,9 +302,9 @@ freetype='void'
 full_csh='/bin/csh'
 full_sed='/bin/sed'
 gcc=''
-gccversion='2.7.2.1'
+gccversion='2.7.2.3'
 gidtype='gid_t'
-glibpth='/usr/shlib  /shlib /lib/pa1.1 /usr/lib/large /lib /usr/lib /usr/lib/386 /lib/386 /lib/large /usr/lib/small /lib/small /usr/ccs/lib /usr/ucblib /usr/local/lib '
+glibpth='/usr/shlib  /shlib /usr/lib/pa1.1 /usr/lib/large /lib /usr/lib /usr/lib/386 /lib/386 /lib/large /usr/lib/small /lib/small /usr/ccs/lib /usr/ucblib /usr/local/lib '
 grep='grep'
 groupcat=''
 groupstype='gid_t'
@@ -317,7 +328,7 @@ i_limits='define'
 i_locale='define'
 i_malloc='define'
 i_math='define'
-i_memory='define'
+i_memory='undef'
 i_ndbm='define'
 i_neterrno='undef'
 i_niin='define'
@@ -325,6 +336,7 @@ i_pwd='define'
 i_rpcsvcdbm='undef'
 i_sfio='undef'
 i_sgtty='undef'
+i_shadow='define'
 i_stdarg='define'
 i_stddef='define'
 i_stdlib='define'
@@ -337,7 +349,7 @@ i_sysioctl='define'
 i_sysndir='undef'
 i_sysparam='define'
 i_sysresrc='define'
-i_sysselct='undef'
+i_sysselct='define'
 i_syssockio=''
 i_sysstat='define'
 i_systime='define'
@@ -364,7 +376,7 @@ installscript='/usr/bin'
 installsitearch='/usr/local/lib/site_perl/i386-linux'
 installsitelib='/usr/local/lib/site_perl'
 intsize='4'
-known_extensions='DB_File Fcntl FileHandle GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
+known_extensions='DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket'
 ksh=''
 large=''
 ld='cc'
@@ -372,7 +384,7 @@ lddlflags='-shared -L/usr/local/lib'
 ldflags=' -L/usr/local/lib'
 less='less'
 lib_ext='.a'
-libc='/lib/libc.so.5.4.23'
+libc=''
 libperl='libperl.a'
 libswanted='sfio net socket inet nsl nm ndbm gdbm dbm db malloc dl dld ld sun m c cposix posix ndir dir crypt ucb BSD PW x'
 line='line'
@@ -382,6 +394,7 @@ ln='ln'
 lns='/bin/ln -s'
 locincpth='/usr/local/include /opt/local/include /usr/gnu/include /opt/gnu/include /usr/GNU/include /opt/GNU/include'
 loclibpth='/usr/local/lib /opt/local/lib /usr/gnu/lib /opt/gnu/lib /usr/GNU/lib /opt/GNU/lib'
+longsize='4'
 lp=''
 lpr=''
 ls='ls'
@@ -410,7 +423,7 @@ mv=''
 myarchname='i586-linux'
 mydomain='.bazilians.org'
 myhostname='kitchen'
-myuname='linux kitchen 2.0.27 #3 wed jan 1 12:41:58 pst 1997 i586 unknown '
+myuname='linux kitchen 2.0.34 #2 fri may 22 00:08:40 pdt 1998 i586 unknown '
 n='-n'
 nm_opt=''
 nm_so_opt='--dynamic'
@@ -424,7 +437,7 @@ orderlib='false'
 package='perl5'
 pager='/usr/bin/less'
 passcat=''
-patchlevel='3'
+patchlevel='4'
 path_sep=':'
 perl='perl'
 perladmin='none'
@@ -442,7 +455,7 @@ ranlib=':'
 rd_nodata='-1'
 rm='rm'
 rmail=''
-runnm='true'
+runnm='false'
 scriptdir='/usr/bin'
 scriptdirexp='/usr/bin'
 sed='sed'
@@ -450,9 +463,9 @@ selecttype='fd_set *'
 sendmail='sendmail'
 sh='/bin/sh'
 shar=''
-shmattype='char *'
+shmattype='void *'
+shortsize='2'
 shrpenv=''
-sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 6 17 29 '
 signal_t='void'
 sitearch='/usr/local/lib/site_perl/i386-linux'
 sitearchexp='/usr/local/lib/site_perl/i386-linux'
@@ -474,11 +487,10 @@ stdchar='char'
 stdio_base='((fp)->_IO_read_base)'
 stdio_bufsiz='((fp)->_IO_read_end - (fp)->_IO_read_base)'
 stdio_cnt='((fp)->_IO_read_end - (fp)->_IO_read_ptr)'
-stdio_filbuf=''
 stdio_ptr='((fp)->_IO_read_ptr)'
 strings='/usr/include/string.h'
 submit=''
-subversion='7'
+subversion='4'
 sysman='/usr/man/man1'
 tail=''
 tar=''
@@ -494,7 +506,7 @@ uname='uname'
 uniq='uniq'
 usedl='define'
 usemymalloc='n'
-usenm='true'
+usenm='false'
 useopcode='true'
 useperlio='undef'
 useposix='true'
@@ -516,14 +528,14 @@ Summary of my $package ($baserev patchlevel $PATCHLEVEL subversion $SUBVERSION)
     osname=$osname, osvers=$osvers, archname=$archname
     uname='$myuname'
     hint=$hint, useposix=$useposix, d_sigaction=$d_sigaction
-    useperlio=$useperlio d_sfio=$d_sfio
+    bincompat3=$bincompat3 useperlio=$useperlio d_sfio=$d_sfio
   Compiler:
     cc='$cc', optimize='$optimize', gccversion=$gccversion
     cppflags='$cppflags'
     ccflags ='$ccflags'
     stdchar='$stdchar', d_stdstdio=$d_stdstdio, usevfork=$usevfork
     voidflags=$voidflags, castflags=$castflags, d_casti32=$d_casti32, d_castneg=$d_castneg
-    intsize=$intsize, alignbytes=$alignbytes, usemymalloc=$usemymalloc, randbits=$randbits
+    intsize=$intsize, alignbytes=$alignbytes, usemymalloc=$usemymalloc, prototype=$prototype
   Linker and Libraries:
     ld='$ld', ldflags ='$ldflags'
     libpth=$libpth
@@ -539,17 +551,27 @@ my $summary_expanded = 0;
 
 sub myconfig {
 	return $summary if $summary_expanded;
-	$summary =~ s/\$(\w+)/$Config{$1}/ge;
+	$summary =~ s{\$(\w+)}
+		     { my $c = $Config{$1}; defined($c) ? $c : 'undef' }ge;
 	$summary_expanded = 1;
 	$summary;
 }
 
 sub FETCH { 
-    # check for cached value (which maybe undef so we use exists not defined)
+    # check for cached value (which may be undef so we use exists not defined)
     return $_[0]->{$_[1]} if (exists $_[0]->{$_[1]});
- 
-    my($value); # search for the item in the big $config_sh string
-    return undef unless (($value) = $config_sh =~ m/^$_[1]='(.*)'\s*$/m);
+
+    # Search for it in the big string 
+    my($value, $start, $marker);
+    $marker = "$_[1]='";
+    # return undef unless (($value) = $config_sh =~ m/^$_[1]='(.*)'\s*$/m);
+    $start = index($config_sh, "\n$marker");
+    return undef if ( ($start == -1) &&  # in case it's first 
+        (substr($config_sh, 0, length($marker)) ne $marker) );
+    if ($start == -1) { $start = length($marker) } 
+        else { $start += length($marker) + 1 }
+    $value = substr($config_sh, $start, 
+        index($config_sh, qq('\n), $start) - $start);
  
     $value = undef if $value eq 'undef'; # So we can say "if $Config{'foo'}".
     $_[0]->{$_[1]} = $value; # cache it
@@ -560,19 +582,23 @@ my $prevpos = 0;
 
 sub FIRSTKEY {
     $prevpos = 0;
-    my($key) = $config_sh =~ m/^(.*?)=/;
-    $key;
+    # my($key) = $config_sh =~ m/^(.*?)=/;
+    substr($config_sh, 0, index($config_sh, '=') );
+    # $key;
 }
 
 sub NEXTKEY {
-    my $pos = index($config_sh, "\n", $prevpos) + 1;
+    my $pos = index($config_sh, qq('\n), $prevpos) + 2;
     my $len = index($config_sh, "=", $pos) - $pos;
     $prevpos = $pos;
     $len > 0 ? substr($config_sh, $pos, $len) : undef;
 }
 
 sub EXISTS { 
-     exists($_[0]->{$_[1]})  or  $config_sh =~ m/^$_[1]=/m; 
+    # exists($_[0]->{$_[1]})  or  $config_sh =~ m/^$_[1]=/m;
+    exists($_[0]->{$_[1]}) or
+    index($config_sh, "\n$_[1]='") != -1 or
+    substr($config_sh, 0, length($_[1])+2) eq "$_[1]='";
 }
 
 sub STORE  { die "\%Config::Config is read-only\n" }
@@ -601,6 +627,9 @@ sub config_vars {
 
 sub TIEHASH { bless {} }
 
+# avoid Config..Exporter..UNIVERSAL search for DESTROY then AUTOLOAD
+sub DESTROY { }
+
 tie %Config, 'Config';
 
 1;
@@ -667,17 +696,23 @@ See also C<-V:name> in L<perlrun/Switches>.
 Here's a more sophisticated example of using %Config:
 
     use Config;
+    use strict;
 
-    defined $Config{sig_name} || die "No sigs?";
-    foreach $name (split(' ', $Config{sig_name})) {
-	$signo{$name} = $i;
-	$signame[$i] = $name;
-	$i++;
-    }   
+    my %sig_num;
+    my @sig_name;
+    unless($Config{sig_name} && $Config{sig_num}) {
+	die "No sigs?";
+    } else {
+	my @names = split ' ', $Config{sig_name};
+	@sig_num{@names} = split ' ', $Config{sig_num};
+	foreach (@names) {
+	    $sig_name[$sig_num{$_}] ||= $_;
+	}   
+    }
 
-    print "signal #17 = $signame[17]\n";
-    if ($signo{ALRM}) { 
-	print "SIGALRM is $signo{ALRM}\n";
+    print "signal #17 = $sig_name[17]\n";
+    if ($sig_num{ALRM}) { 
+	print "SIGALRM is $sig_num{ALRM}\n";
     }   
 
 =head1 WARNING
